abacusai.feature_group_export — AbacusAI documentation

# abacusai.feature_group_export

## Classes

`FeatureGroupExport` | A feature Group Export Job

## Module Contents

class abacusai.feature_group_export.FeatureGroupExport(client, featureGroupExportId=None, failedWrites=None, totalWrites=None, featureGroupVersion=None, connectorType=None, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, status=None, createdAt=None, exportCompletedAt=None, additionalIdColumns=None, error=None, databaseOutputError=None, projectConfig={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A feature Group Export Job

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupExportId (str) – Unique identifier for this export.

    - failedWrites (int) – Number of failed writes.

    - totalWrites (int) – Total number of writes.

    - featureGroupVersion (str) – Version of the feature group being exported.

    - connectorType (str) – The type of connector

    - outputLocation (str) – File Connector location the feature group is being written to.

    - fileFormat (str) – File format being written to output_location.

    - databaseConnectorId (str) – Database connector ID used.

    - objectName (str) – Database connector’s object to write to.

    - writeMode (str) – UPSERT or INSERT for writing to the database connector.

    - databaseFeatureMapping (dict) – Column/feature pairs mapping the features to the database columns.

    - idColumn (str) – ID column to use as the upsert key.

    - status (str) – Current status of the export.

    - createdAt (str) – Timestamp at which the export was created (ISO-8601 format).

    - exportCompletedAt (str) – Timestamp at which the export completed (ISO-8601 format).

    - additionalIdColumns (list[str]) – For database connectors which support it, additional ID columns to use as a complex key for upserting.

    - error (str) – If status is FAILED, this field will be populated with an error.

    - databaseOutputError (bool) – If True, there were errors reported by the database connector while writing.

    - projectConfig (ProjectConfig) – Project config for this feature group.

  feature_group_export_id
  failed_writes
  total_writes
  feature_group_version
  connector_type
  output_location
  file_format
  database_connector_id
  object_name
  write_mode
  database_feature_mapping
  id_column
  status
  created_at
  export_completed_at
  additional_id_columns
  error
  database_output_error
  project_config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  get_feature_group_version_export_download_url()

    Get a link to download the feature group version.

    Parameters:

      feature_group_export_id (str) – Unique identifier of the Feature Group Export to get a signed URL for.

    Returns:

      Instance containing the download URL and expiration time for the Feature Group Export.

    Return type:

      FeatureGroupExportDownloadUrl

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      FeatureGroupExport

  describe()

    A feature group export

    Parameters:

      feature_group_export_id (str) – Unique identifier of the feature group export.

    Returns:

      The feature group export object.

    Return type:

      FeatureGroupExport

  get_connector_errors()

    Returns a stream containing the write errors of the feature group export database connection, if any writes failed to the database connector.

    Parameters:

      feature_group_export_id (str) – Unique identifier of the feature group export to get the errors for.

  wait_for_results(timeout=3600)

    A waiting call until feature group export is created.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_for_export(timeout=3600)

    A waiting call until feature group export is created.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the feature group export.

    Returns:

      A string describing the status of a feature group export (pending, complete, etc.).

    Return type:

      str